from linux_profile.base.settings import Settings


class Execute(Settings):

    def __init__(self, **kwargs) -> None:
        super().__init__(**kwargs)
